==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/storage/ndb/src/kernel/vm/Slot.hpp <==
/*
   Copyright (c) 2018, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef SLOT_HPP
#define SLOT_HPP

#include "blocks/record_types.hpp"
#include "ndb_global.h"
#include "ndb_limits.h"
#include "ndb_types.h"
#include "vm/Pool.hpp"

#define JAM_FILE_ID 507

// Slot must have standard layout

class Slot
{
 public:
  static constexpr Uint32 TYPE_ID = RT_FREE;
  Slot();
  Uint32 m_magic;
  Uint32 nextList;
  Uint32 prevList;
};

template <typename SlotPool>
class LocalSlotPool
{
 public:
  typedef Slot Type;

  LocalSlotPool(SlotPool* pool, Uint32 slot_size);
  void getPtr(Ptr<Slot>& ptr) const;

 private:
  SlotPool* const m_pool;
  const Uint32 m_slot_size;
};

inline Slot::Slot()
    : m_magic(Magic::make(TYPE_ID)), nextList(RNIL), prevList(RNIL)
{
}

template <typename P>
inline LocalSlotPool<P>::LocalSlotPool(P* pool, Uint32 slot_size)
    : m_pool(pool), m_slot_size(slot_size)
{
}

template <typename P>
inline void LocalSlotPool<P>::getPtr(Ptr<Slot>& ptr) const
{
  m_pool->getPtr(ptr, m_slot_size);
}

#undef JAM_FILE_ID

#endif

==> percona-xtrabackup-8.3.0-1.tar.gz: percona-xtrabackup-8.3.0-1/storage/ndb/src/kernel/vm/Slot.hpp <==
/*
   Copyright (c) 2018, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef SLOT_HPP
#define SLOT_HPP

#include "blocks/record_types.hpp"
#include "ndb_global.h"
#include "ndb_limits.h"
#include "ndb_types.h"
#include "vm/Pool.hpp"

#define JAM_FILE_ID 507

// Slot must have standard layout

class Slot {
 public:
  static constexpr Uint32 TYPE_ID = RT_FREE;
  Slot();
  Uint32 m_magic;
  Uint32 nextList;
  Uint32 prevList;
};

template <typename SlotPool>
class LocalSlotPool {
 public:
  typedef Slot Type;

  LocalSlotPool(SlotPool *pool, Uint32 slot_size);
  void getPtr(Ptr<Slot> &ptr) const;

 private:
  SlotPool *const m_pool;
  const Uint32 m_slot_size;
};

inline Slot::Slot()
    : m_magic(Magic::make(TYPE_ID)), nextList(RNIL), prevList(RNIL) {}

template <typename P>
inline LocalSlotPool<P>::LocalSlotPool(P *pool, Uint32 slot_size)
    : m_pool(pool), m_slot_size(slot_size) {}

template <typename P>
inline void LocalSlotPool<P>::getPtr(Ptr<Slot> &ptr) const {
  m_pool->getPtr(ptr, m_slot_size);
}

#undef JAM_FILE_ID

#endif
